@@ -56,7 +56,7 @@ WKGTK_init::~WKGTK_init() {
     if (loop) {
         g_main_loop_unref(loop);
     }
-    jlog << iclog::loglevel::info << iclog::category::CORE
+    wkJlog << iclog::loglevel::info << iclog::category::CORE
          << "GTK main loop exiting." << std::endl;
 }
 
@@ -73,7 +73,7 @@ WKGTK_init::~WKGTK_init() {
 icGTK::icGTK(XvfbMode runMode)
     : tk(handle_xvfb_daemon()),
       runMode(runMode) {
-    jlog << iclog::loglevel::info << iclog::category::CORE
+    wkJlog << iclog::loglevel::info << iclog::category::CORE
          << "Inplicare initialising  WebKitGTK." << std::endl;
 }
 
@@ -120,33 +120,33 @@ WKGTK_init icGTK::handle_xvfb_daemon() {
     bool  headless = false;
     if ((XOpenDisplay(display) == nullptr) && (wl_display_connect(wayland) == nullptr)) {
         headless = true;
-        jlog << iclog::loglevel::info << iclog::category::CORE
+        wkJlog << iclog::loglevel::info << iclog::category::CORE
              << "Preparing headless mode..." << std::endl;
     }
 
     sd_bus *bus = nullptr;
 
     if (headless) {
-        if (sd_bus_open_system(&bus) < 0) {
-            jlog << iclog::loglevel::error << iclog::category::CORE << iclog_FUNCTION
-                 << "Failed to connect to system bus; "
-                 << "the application cannot continue and will now exit" << std::endl;
-            exit(1);
+
+        int r = sd_bus_open_system(&bus);
+        if (r < 0) {
+            wkJlog << iclog::loglevel::error << "D-Bus Connection Failed: " << strerror(-r) << std::endl;
+            throw std::runtime_error("Failed to connect to system bus: " + std::string(strerror(-r)));
         }
 
         std::string unit  = "xvfb_2eservice"; // escaped 'xvfb.service'
         std::string state = check_xvfb(bus, unit);
 
         if (state != "active") {
-            jlog << iclog::loglevel::error << iclog::category::CORE << iclog_FUNCTION
+            wkJlog << iclog::loglevel::error << iclog::category::CORE << iclog_FUNCTION
                  << unit << " not active, starting..." << std::endl;
             if (EXIT_SUCCESS == start_service(bus)) {
-                jlog << iclog::loglevel::debug << iclog::category::CORE
+                wkJlog << iclog::loglevel::debug << iclog::category::CORE
                      << " state: " << check_xvfb(bus, unit) << std::endl;
 
                 while (state != "active") {
                     state = check_xvfb(bus, unit);
-                    jlog << iclog::loglevel::debug << iclog::category::CORE << unit
+                    wkJlog << iclog::loglevel::debug << iclog::category::CORE << unit
                          << " state: " << state << std::endl;
                     std::this_thread::sleep_for(std::chrono::milliseconds(200));
                 }
@@ -158,13 +158,13 @@ WKGTK_init icGTK::handle_xvfb_daemon() {
     }
 
     if (gtk_init_check(NULL, NULL)) {
-        jlog << iclog::loglevel::info << iclog::category::CORE
+        wkJlog << iclog::loglevel::info << iclog::category::CORE
              << "WEBKIT2GTK Initialised." << std::endl;
     } else {
-        jlog << iclog::loglevel::error << iclog::category::CORE
-             << "GTK initialization failed; "
-             << "the application cannot continue and will now exit." << std::endl;
-        exit(1);
+        wkJlog << iclog::loglevel::error << iclog::category::CORE
+             << "GTK initialization failed"
+             << std::endl;
+        throw std::runtime_error("GTK initialization failed");
     }
 
     return (WKGTK_init());
@@ -235,13 +235,13 @@ bool icGTK::start_service(sd_bus *bus) {
     );
 
     if (r < 0) {
-        jlog << iclog::loglevel::error << iclog::category::CORE
+        wkJlog << iclog::loglevel::error << iclog::category::CORE
              << "Failed to start unit: " << error.message << std::endl;
     } else {
         // Read the returned job path
         r = sd_bus_message_read(reply, "o", &job_path);
         if (r >= 0) {
-            jlog << iclog::loglevel::debug << iclog::category::CORE
+            wkJlog << iclog::loglevel::debug << iclog::category::CORE
                  << "Started job: " << job_path << std::endl;
         }
     }
@@ -284,13 +284,13 @@ bool icGTK::stop_service(sd_bus *bus) {
     );
 
     if (r < 0) {
-        jlog << iclog::loglevel::error << iclog::category::CORE
+        wkJlog << iclog::loglevel::error << iclog::category::CORE
              << "Failed to Stop unit: " << error.message << std::endl;
     } else {
         // Read the returned job path
         r = sd_bus_message_read(reply, "o", &job_path);
         if (r >= 0) {
-            jlog << iclog::loglevel::debug << iclog::category::CORE
+            wkJlog << iclog::loglevel::debug << iclog::category::CORE
                  << "Stopped job: " << job_path << std::endl;
         }
     }
@@ -317,7 +317,7 @@ struct PDFprinterUserData {
  */
 static void print_finished(WebKitPrintOperation *print_operation __attribute__((unused)), void *user_data) {
     g_main_loop_quit(((PDFprinterUserData *)user_data)->main_loop);
-    jlog << iclog::loglevel::debug << iclog::category::CORE
+    wkJlog << iclog::loglevel::debug << iclog::category::CORE
          << "Printing complte; quitting." << std::endl;
 }
 
@@ -577,7 +577,7 @@ static void javascript_callback(
     );
 
     if (error) {
-        jlog << iclog::loglevel::error << iclog::category::CORE
+        wkJlog << iclog::loglevel::error << iclog::category::CORE
              << "JavaScript error: " << error->message << std::endl;
         g_error_free(error);
         return;
@@ -587,19 +587,19 @@ static void javascript_callback(
     gchar *json_string = jsc_value_to_string(js_result);
 
     if (!json_string) {
-        jlog << iclog::loglevel::error << iclog::category::CORE
+        wkJlog << iclog::loglevel::error << iclog::category::CORE
              << "Failed to convert JavaScript result to string" << std::endl;
         g_object_unref(js_result);
         return;
     }
 
-    jlog << iclog::loglevel::debug << iclog::category::CORE
+    wkJlog << iclog::loglevel::debug << iclog::category::CORE
          << "Extracted JSON: " << json_string << std::endl;
 
     // Parse JSON with json-c
     json_object *root = json_tokener_parse(json_string);
     if (!root) {
-        jlog << iclog::loglevel::error << iclog::category::CORE
+        wkJlog << iclog::loglevel::error << iclog::category::CORE
              << "Failed to parse JSON" << std::endl;
         g_free(json_string);
         g_object_unref(js_result);
@@ -631,7 +631,7 @@ static void javascript_callback(
     //             {string(), 0.0f, 0.0f, 0.0f,  0.0f,   0.0f,  0.0f,  0   }
     //         });
 
-    //         jlog << iclog::loglevel::debug << iclog::category::CORE
+    //         wkJlog << iclog::loglevel::debug << iclog::category::CORE
     //              << "Finding Index: " << key << " -> page: " << page
     //              << " pos: (" << x << "," << y << ")" << std::endl;
     //     }
@@ -660,7 +660,7 @@ static void javascript_callback(
                 {std::string(), 0.0f, 0.0f, 0.0f,  0.0f,   0.0f,  0.0f,  0   }
             });
 
-            jlog << iclog::loglevel::debug << iclog::category::CORE
+            wkJlog << iclog::loglevel::debug << iclog::category::CORE
                  << "Finding Index: " << (id ? id : "null") << " -> page: " << page
                  << " pos: (" << x << "," << y << ")" << std::endl;
         }
@@ -688,7 +688,7 @@ static void javascript_callback(
                 });
 
             } catch (std::out_of_range e) {
-                jlog << iclog::loglevel::warning << iclog::category::LIB
+                wkJlog << iclog::loglevel::warning << iclog::category::LIB
                      << e.what()
                      << std::endl;
             }
@@ -699,7 +699,7 @@ static void javascript_callback(
         for (std::pair<std::string, PDFprinter::linkData> t : tData) {
             if (s.linkName.compare(t.first) == 0) {
                 s.target = t.second;
-                jlog << iclog::loglevel::debug << iclog::category::CORE
+                wkJlog << iclog::loglevel::debug << iclog::category::CORE
                      << "\nIndex: " << s.linkName << " -> page: " << s.index.pageNo << " pos: (" << s.index.xPos << "," << s.index.yPos << ") size: (" << s.index.w << "," << s.index.h << ")\n"
                      << "Target: " << s.linkName << " -> title: " << s.target.title << " -> page: " << s.target.pageNo << " pos: (" << s.target.xPos << "," << s.target.yPos << ") size: (" << s.target.w << "," << s.target.h << ")"
                      << std::endl;
@@ -731,7 +731,7 @@ static void web_view_load_changed(WebKitWebView *web_view, WebKitLoadEvent load_
 
     switch (load_event) {
         case WEBKIT_LOAD_STARTED:
-            jlog << iclog::loglevel::debug << iclog::category::CORE
+            wkJlog << iclog::loglevel::debug << iclog::category::CORE
                  << "WEBKIT LOAD STARTED." << std::endl;
             /* New load, we have now a provisional URI */
             // printf("WEBKIT_LOAD_STARTED\n");
@@ -740,7 +740,7 @@ static void web_view_load_changed(WebKitWebView *web_view, WebKitLoadEvent load_
         case WEBKIT_LOAD_REDIRECTED:
             break;
         case WEBKIT_LOAD_COMMITTED:
-            jlog << iclog::loglevel::debug << iclog::category::CORE
+            wkJlog << iclog::loglevel::debug << iclog::category::CORE
                  << "The load is being performed. Current URI is the final one and it "
                     "won't change unless a new "
                  << "load is requested or a navigation within the same page is "
@@ -754,7 +754,7 @@ static void web_view_load_changed(WebKitWebView *web_view, WebKitLoadEvent load_
 
             // --- REMOVED ---
             // case WEBKIT_LOAD_FINISHED:
-            //     jlog << iclog::loglevel::debug << iclog::category::CORE
+            //     wkJlog << iclog::loglevel::debug << iclog::category::CORE
             //          << "printing pdf file: "
             //          << gtk_print_settings_get(
             //                 ((PDFprinterUserData *)user_data)->print_settings,
@@ -770,7 +770,7 @@ static void web_view_load_changed(WebKitWebView *web_view, WebKitLoadEvent load_
 
             // --- ADDED ---
         case WEBKIT_LOAD_FINISHED:
-            jlog << iclog::loglevel::debug << iclog::category::CORE
+            wkJlog << iclog::loglevel::debug << iclog::category::CORE
                  << "WEBKIT LOAD FINISHED - extracting positions" << std::endl;
 
             auto js = [&user_data]() {
@@ -790,7 +790,7 @@ static void web_view_load_changed(WebKitWebView *web_view, WebKitLoadEvent load_
                 // Enable JavaScript for extraction
                 WebKitSettings *view_settings = webkit_web_view_get_settings(web_view);
                 webkit_settings_set_enable_javascript(view_settings, true);
-                jlog << iclog::loglevel::debug << iclog::category::CORE
+                wkJlog << iclog::loglevel::debug << iclog::category::CORE
                      << "Extracting coordinates using:\n"
                      << js()
                      << std::endl;
@@ -808,7 +808,7 @@ static void web_view_load_changed(WebKitWebView *web_view, WebKitLoadEvent load_
 
             } else {
                 // No extraction needed — proceed directly to print
-                jlog << iclog::loglevel::debug << iclog::category::CORE
+                wkJlog << iclog::loglevel::debug << iclog::category::CORE
                      << "No index extraction required — printing directly" << std::endl;
 
                 WebKitPrintOperation *print_operation = ((PDFprinterUserData *)user_data)->print_operation;
@@ -837,7 +837,7 @@ static int cb_worker(struct html2pdf_params *p) {
     user_data.doIndex  = p->doIndex;
     user_data.tocPage  = p->tocPage;
 
-    jlog << iclog::loglevel::debug << iclog::category::CORE
+    wkJlog << iclog::loglevel::debug << iclog::category::CORE
          << "Applying print settings" << std::endl;
     GtkPrintSettings *print_settings = gtk_print_settings_new();
     gtk_print_settings_set_printer(print_settings, "Print to File");
@@ -847,7 +847,7 @@ static int cb_worker(struct html2pdf_params *p) {
 
     if (p->key_file_data != NULL) {
 
-        jlog << iclog::loglevel::debug << iclog::category::CORE
+        wkJlog << iclog::loglevel::debug << iclog::category::CORE
              << "Applying page setup:\n"
              << p->key_file_data << std::endl;
         GKeyFile *key_file = g_key_file_new();
@@ -877,7 +877,7 @@ static int cb_worker(struct html2pdf_params *p) {
 
     if (p->default_stylesheet) {
 
-        jlog << iclog::loglevel::debug << iclog::category::CORE
+        wkJlog << iclog::loglevel::debug << iclog::category::CORE
              << "Injecting style sheet:\n"
              << p->default_stylesheet << std::endl;
         user_content_manager = webkit_user_content_manager_new();
@@ -891,7 +891,7 @@ static int cb_worker(struct html2pdf_params *p) {
         webkit_user_content_manager_add_style_sheet(user_content_manager, user_stylesheet);
         g_object_set_property(G_OBJECT(web_view), "user-content-manager", (GValue *)(user_content_manager));
     } else {
-        jlog << iclog::loglevel::debug << iclog::category::CORE
+        wkJlog << iclog::loglevel::debug << iclog::category::CORE
              << "Injecting stylesheet: No explicit style sheet set; skipping:"
              << std::endl;
     }
@@ -911,7 +911,7 @@ static int cb_worker(struct html2pdf_params *p) {
     g_signal_connect(web_view, "load-changed", G_CALLBACK(web_view_load_changed), &user_data);
     if (p->html_txt != NULL) {
         // webkit_web_view_load_html(web_view, p->html_txt, "file:///tmp");
-        jlog << iclog::loglevel::debug << iclog::category::CORE
+        wkJlog << iclog::loglevel::debug << iclog::category::CORE
              << "Setting base URI: " << p->in_uri
              << std::endl;
         webkit_web_view_load_html(web_view, p->html_txt, p->in_uri);
@@ -1002,7 +1002,7 @@ PDFprinter::~PDFprinter() {
 std::string PDFprinter::read_file(const std::string &fullPath) {
     std::ifstream file(fullPath);
     if (file.fail()) {
-        jlog << iclog::loglevel::debug << iclog::category::CORE
+        wkJlog << iclog::loglevel::debug << iclog::category::CORE
              << "Cannot find the file specified: " << fullPath << std::endl;
         return ("");
     }
@@ -1048,7 +1048,7 @@ void PDFprinter::read_file_to_blob() {
         throw std::runtime_error("Error reading PDF file contents");
     }
 
-    jlog << iclog::loglevel::error << iclog::category::CORE << iclog_FUNCTION
+    wkJlog << iclog::loglevel::error << iclog::category::CORE << iclog_FUNCTION
          << "Generated BLOB: " << path << " size=" << m_binPDF.size() << std::endl;
 }
 
@@ -1070,7 +1070,7 @@ std::string PDFprinter::generate_uuid_string() {
     }
 
     std::string uuid = ss.str();
-    jlog << iclog::loglevel::debug << iclog::category::CORE << iclog_FUNCTION
+    wkJlog << iclog::loglevel::debug << iclog::category::CORE << iclog_FUNCTION
          << "UUID generated: " << uuid << std::endl;
 
     return uuid;
@@ -1237,7 +1237,7 @@ void PDFprinter::make_pdf() {
 
     // GENERATE BLOB (if requested)
     if (m_makeBlob) {
-        jlog << iclog::loglevel::error << iclog::category::CORE << iclog_FUNCTION
+        wkJlog << iclog::loglevel::error << iclog::category::CORE << iclog_FUNCTION
              << "Making BLOB" << std::endl;
         read_file_to_blob();
     }
